/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/*
 * This file is part of libosso-abook
 *
 * Copyright (C) 2006 Nokia Corporation. All rights reserved.
 *
 * Contact: Onne Gorter <onne.gorter@nokia.com>
 */

#ifndef __OSSO_ABOOK_ADD_USERNAME_DIALOG_H__
#define __OSSO_ABOOK_ADD_USERNAME_DIALOG_H__

#include <gtk/gtkdialog.h>
#include <libebook/e-book.h>

G_BEGIN_DECLS

/**
 * OssoABookAddUsernameDialogMode:
 * @TYPE_CHAT: Add a chat username
 * @TYPE_VOIP: Add a VOIP/call username
 * @TYPE_EMAIL: Add an email address
 *
 * What type of account will be added to the contact.
 */
typedef enum {
        TYPE_CHAT,
        TYPE_VOIP,
        TYPE_EMAIL
} OssoABookAddUsernameDialogMode;

#define OSSO_ABOOK_TYPE_ADD_USERNAME_DIALOG \
                (osso_abook_add_username_dialog_get_type ())
#define OSSO_ABOOK_ADD_USERNAME_DIALOG(obj) \
                (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
                 OSSO_ABOOK_TYPE_ADD_USERNAME_DIALOG, \
                 OssoABookAddUsernameDialog))
#define OSSO_ABOOK_ADD_USERNAME_DIALOG_CLASS(klass) \
                (G_TYPE_CHECK_CLASS_CAST ((klass), \
                 OSSO_ABOOK_TYPE_ADD_USERNAME_DIALOG, \
                 OssoABookAddUsernameDialogClass))
#define OSSO_ABOOK_IS_ADD_USERNAME_DIALOG(obj) \
                (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
                 OSSO_ABOOK_TYPE_ADD_USERNAME_DIALOG))
#define OSSO_ABOOK_IS_ADD_USERNAME_DIALOG_CLASS(klass) \
                (G_TYPE_CHECK_CLASS_TYPE ((klass), \
                 OSSO_ABOOK_TYPE_ADD_USERNAME_DIALOG))
#define OSSO_ABOOK_ADD_USERNAME_DIALOG_GET_CLASS(obj) \
                (G_TYPE_INSTANCE_GET_CLASS ((obj), \
                 OSSO_ABOOK_TYPE_ADD_USERNAME_DIALOG, \
                 OssoABookAddUsernameDialogClass))

typedef struct _OssoABookAddUsernameDialogPrivate OssoABookAddUsernameDialogPrivate;

typedef struct {
        GtkDialog parent;
        OssoABookAddUsernameDialogPrivate *priv;
} OssoABookAddUsernameDialog;

typedef struct {
	GtkDialogClass parent_class;
} OssoABookAddUsernameDialogClass;

GType
osso_abook_add_username_dialog_get_type (void) G_GNUC_CONST;

GtkWidget *
osso_abook_add_username_dialog_new (OssoABookAddUsernameDialogMode mode);

void
osso_abook_add_username_dialog_set_contact (OssoABookAddUsernameDialog *dialog,
                                            EContact                   *contact);

void
osso_abook_add_username_dialog_set_book_view (OssoABookAddUsernameDialog *dialog,
                                              EBookView                  *book_view);

G_END_DECLS

#endif /* __OSSO_ABOOK_ADD_USERNAME_DIALOG_H__ */
