/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/*
 * This file is part of libosso-abook
 *
 * Copyright (C) 2007  Nokia Corporation.  All rights reserved.
 *
 * Contact: Onne Gorter <onne.gorter@nokia.com>
 */

#ifndef __OSSO_ABOOK_AVATAR_H__
#define __OSSO_ABOOK_AVATAR_H__

#include <glib-object.h>
#include <gdk-pixbuf/gdk-pixbuf.h>

G_BEGIN_DECLS

#define OSSO_ABOOK_TYPE_AVATAR \
                (osso_abook_avatar_get_type ())
#define OSSO_ABOOK_AVATAR(obj) \
                (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
                 OSSO_ABOOK_TYPE_AVATAR, \
                 OssoABookAvatar))
#define OSSO_ABOOK_IS_AVATAR(obj) \
                (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
                 OSSO_ABOOK_TYPE_AVATAR))
#define OSSO_ABOOK_AVATAR_CLASS(klass) \
                (G_TYPE_CHECK_CLASS_CAST ((klass), \
                 OSSO_ABOOK_TYPE_AVATAR, \
                 OssoABookAvatarClass))
#define OSSO_ABOOK_IS_AVATAR_CLASS(klass) \
                (G_TYPE_CHECK_CLASS_TYPE ((klass), \
                 OSSO_ABOOK_TYPE_AVATAR))
#define OSSO_ABOOK_AVATAR_GET_CLASS(klass) \
                (G_TYPE_INSTANCE_GET_CLASS ((klass), \
                 OSSO_ABOOK_TYPE_AVATAR, \
                 OssoABookAvatarClass))

typedef struct _OssoABookAvatar         OssoABookAvatar;
typedef struct _OssoABookAvatarPrivate  OssoABookAvatarPrivate;
typedef struct _OssoABookAvatarClass    OssoABookAvatarClass;

struct _OssoABookAvatar {
        GObject parent_instance;

        /*< private >*/
        OssoABookAvatarPrivate *priv;
};

struct _OssoABookAvatarClass {
        GObjectClass parent_class;
        
        /* vfuncs, not signals */
        GdkPixbuf *(* get_image)        (OssoABookAvatar *avatar);
        GdkPixbuf *(* get_image_scaled) (OssoABookAvatar *avatar,
                                         gint             width,
                                         gint             height,
                                         gboolean         crop);

        /* signals */
        void (*load_error) (OssoABookAvatar *avatar,
                            const GError    *error);
};

GType
osso_abook_avatar_get_type         (void) G_GNUC_CONST;

GdkPixbuf *
osso_abook_avatar_get_image        (OssoABookAvatar *avatar);

GdkPixbuf *
osso_abook_avatar_get_image_scaled (OssoABookAvatar *avatar,
                                    gint             width,
                                    gint             height,
                                    gboolean         crop);

gboolean
osso_abook_avatar_is_done_loading  (OssoABookAvatar *avatar);


/* for implementations use only */

void
_osso_abook_avatar_load_error       (OssoABookAvatar *avatar,
                                     const GError    *error);

void
_osso_abook_avatar_set_done_loading (OssoABookAvatar *avatar,
                                     gboolean         done_loading);

gboolean
_osso_abook_avatar_get_done_loading (OssoABookAvatar *avatar);

G_END_DECLS

#endif /* __OSSO_ABOOK_AVATAR_H__ */
