/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/*
 * This file is part of libosso-abook
 *
 * Copyright (C) 2006 Nokia Corporation. All rights reserved.
 *
 * Contact: Onne Gorter <onne.gorter@nokia.com>
 */

#ifndef __OSSO_ABOOK_CONTACT_H__
#define __OSSO_ABOOK_CONTACT_H__

#include <libebook/e-book.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gtk/gtkwindow.h>
#include <time.h>

#include "osso-abook-manual-group.h"
#include "osso-abook-account.h"
#include "osso-abook-avatar.h"

G_BEGIN_DECLS

typedef enum {
        NAME_FIRST,
        NAME_LAST,
} OssoABookNameOrder;

void
osso_abook_contact_commit            (EContact                 *contact,
                                      gboolean                  new,
                                      EBook                    *book,
                                      GtkWindow                *window);

void
osso_abook_contact_delete            (EContact                 *contact,
                                      EBook                    *book,
                                      GtkWindow                *window);

void
osso_abook_contact_delete_many (GList     *contacts,
                                EBook     *book,
                                GtkWindow *window);

GdkPixbuf *
osso_abook_contact_get_photo         (EContact                 *contact);

void
osso_abook_contact_set_pixbuf        (EContact                 *contact,
                                      GdkPixbuf                *pixbuf,
                                      EBook                    *book,
                                      GtkWindow                *window);
void
osso_abook_contact_set_photo         (EContact                 *contact,
                                      const char               *filename,
                                      EBook                    *book,
                                      GtkWindow                *window);

OssoABookAvatar *
osso_abook_contact_get_avatar        (EContact                 *contact,
                                      const char               *username,
                                      const char               *vcardfield);

GdkPixbuf *
osso_abook_contact_get_avatar_pixbuf (EContact                 *contact,
                                      const char               *username,
                                      const char               *vcardfield);
GList *
osso_abook_contact_get_accounts_with_capabilities (EContact          *contact,
                                                   OssoABookCapsFlags flags);

GList *
osso_abook_contact_get_accounts      (EContact                 *contact,
                                      OssoABookAccountTypeFlags flags);

GList *
osso_abook_contact_get_groups        (EContact                 *contact);

void
osso_abook_contact_add_group         (EContact                 *contact,
                                      OssoABookManualGroup     *group,
                                      EBook                    *book,
                                      GtkWindow                *window);

void
osso_abook_contact_remove_group      (EContact                 *contact,
                                      OssoABookManualGroup     *group,
                                      EBook                    *book,
                                      GtkWindow                *window);

void
osso_abook_contact_rename_group      (EContact                 *contact,
                                      const char               *old_name,
                                      const char               *new_name,
                                      EBook                    *book,
                                      GtkWindow                *window);
void
osso_abook_contact_replace_group (EContact                    *contact,
                                  OssoABookManualGroup        *old_group,
                                  OssoABookManualGroup        *new_group,
                                  EBook                       *book,
                                  GtkWindow                   *window);

void
osso_abook_contact_update_last_used (EContact  *contact);

time_t
osso_abook_contact_get_last_used    (EContact                 *contact);

int
osso_abook_contact_compare_last_used (EContact  *a_contact, EContact *b_contact);

void
osso_abook_contact_set_blocked      (EContact                 *contact,
                                     gboolean                  blocked,
                                     EBook                    *book,
                                     GtkWindow                *window);

gboolean
osso_abook_contact_get_blocked      (EContact                 *contact); 

gboolean
osso_abook_contact_get_deleted      (EContact                 *contact);

void
osso_abook_contact_set_manual (EContact  *contact,
                               gboolean   manual,
                               EBook     *book,
                               GtkWindow *window);

gboolean
osso_abook_contact_get_manual       (EContact                 *contact);

gboolean
osso_abook_contact_get_visible      (EContact                 *contact);

gboolean
osso_abook_contact_can_block        (EContact                 *contact,
                                     const char              **infoprint);

gboolean
osso_abook_contact_can_request_auth (EContact                 *contact,
                                     const char              **infoprint);

const char *
osso_abook_contact_get_name         (EContact                 *contact);

const char *
osso_abook_contact_get_display_name (EContact                 *contact);

void
osso_abook_contact_initiate_chat    (EContact                 *contact,
                                     EBook                    *book,
                                     GtkWindow                *window);

void
osso_abook_contact_initiate_call    (EContact                 *contact,
                                     EBook                    *book,
                                     GtkWindow                *window);

gboolean
osso_abook_contact_send_email       (EContact                 *contact,
                                     EBook                    *book,
                                     GtkWindow                *window);
gboolean
osso_abook_contact_has_url (EContact                          *contact,
                            const char                       **infoprint);

void
osso_abook_contact_goto_url (EContact *contact);

void
osso_abook_contact_vcard_clean_accounts (EContact                 *contact);

void
osso_abook_contact_vcard_clean      (EContact                 *contact);

void
osso_abook_contact_set_contact_flag (EContact   *contact,
                                     const char *flag,
                                     gboolean    flag_set);

void
osso_abook_contact_add_manual (EBook *book,
                               const char *vcard,
                               const char *bound,
                               const char *username,
                               GtkWindow *window);


int
osso_abook_contact_matches_chat_user (EContact *contact,
                                      const char *vcard,
                                      const char *username,
                                      const char *bound);

const char *
_osso_abook_contact_get_name_with_order (EContact *contact,
                                         OssoABookNameOrder order);

G_END_DECLS

#endif /* __OSSO_ABOOK_CONTACT_H__ */
