#ifndef __OSSO_ABOOK_DEBUG_H__
#define __OSSO_ABOOK_DEBUG_H__

#include <glib.h>

G_BEGIN_DECLS

typedef enum {
        OSSO_ABOOK_DEBUG_EDS            = 1 << 0,
        OSSO_ABOOK_DEBUG_GTK            = 1 << 1,
        OSSO_ABOOK_DEBUG_HILDON         = 1 << 2,
        OSSO_ABOOK_DEBUG_CONTACT_ADD    = 1 << 3,
        OSSO_ABOOK_DEBUG_CONTACT_REMOVE = 1 << 4,
        OSSO_ABOOK_DEBUG_CONTACT_UPDATE = 1 << 5,
        OSSO_ABOOK_DEBUG_VCARD          = 1 << 6,
        OSSO_ABOOK_DEBUG_AVATAR         = 1 << 7,
        OSSO_ABOOK_DEBUG_EXTENSION      = 1 << 8,
        OSSO_ABOOK_DEBUG_GALAGO         = 1 << 9,
        OSSO_ABOOK_DEBUG_MC             = 1 << 10,
        OSSO_ABOOK_DEBUG_CAPS           = 1 << 11,
        OSSO_ABOOK_DEBUG_GENERIC        = 1 << 12,
        OSSO_ABOOK_DEBUG_ALL            = -1
} OssoABookDebugFlags;

/* exported, but you should never use it */
extern guint osso_abook_debug_flags;

void osso_abook_debug_init (void);

#ifdef OSSO_ABOOK_DEBUG
#define OSSO_ABOOK_NOTE(type,format,a...)       G_STMT_START {          \
        if (osso_abook_debug_flags & OSSO_ABOOK_DEBUG_##type) {         \
                g_log (OSSO_ABOOK_DEBUG_##type == OSSO_ABOOK_DEBUG_ALL ? \
                       NULL : "[" #type "]", G_LOG_LEVEL_DEBUG,         \
                       G_STRLOC ": " format, ##a);                      \
        }                                       } G_STMT_END
#define OSSO_ABOOK_MARK(type)                   G_STMT_START {          \
        if (osso_abook_debug_flags & OSSO_ABOOK_DEBUG_##type) {         \
                g_log (OSSO_ABOOK_DEBUG_##type == OSSO_ABOOK_DEBUG_ALL ? \
                       NULL : "[" #type "]", G_LOG_LEVEL_DEBUG,         \
                       G_STRLOC ": -- mark --");                        \
        }                                       } G_STMT_END
#else
#define OSSO_ABOOK_NOTE(...)
#define OSSO_ABOOK_MARK(...)
#endif

#define _debug(format...)                OSSO_ABOOK_NOTE (GENERIC, format)
#define _debug_always(format...)         OSSO_ABOOK_NOTE (ALL, format)
#define _debug_eds(format...)            OSSO_ABOOK_NOTE (EDS, format)
#define _debug_gtk(format...)            OSSO_ABOOK_NOTE (GTK, format)
#define _debug_avatar(format...)         OSSO_ABOOK_NOTE (AVATAR, format)
#define _debug_extension(format...)      OSSO_ABOOK_NOTE (EXTENSION, format)
#define _debug_galago(format...)         OSSO_ABOOK_NOTE (GALAGO, format)
#define _debug_mc(format...)             OSSO_ABOOK_NOTE (MC, format)
#define _debug_caps(format...)           OSSO_ABOOK_NOTE (CAPS, format)

G_END_DECLS

#endif /* __OSSO_ABOOK_DEBUG_H__ */
