/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/*
 * This file is part of libosso-abook
 *
 * Copyright (C) 2006 Nokia Corporation. All rights reserved.
 *
 * Contact: Onne Gorter <onne.gorter@nokia.com>
 */

#ifndef __OSSO_ABOOK_PROGRAM_H__
#define __OSSO_ABOOK_PROGRAM_H__

G_BEGIN_DECLS

#include <glib-object.h>

#include <libosso.h>
#include <libmissioncontrol/mission-control.h>

#define OSSO_ABOOK_TYPE_PROGRAM                             \
                (osso_abook_program_get_type ())
#define OSSO_ABOOK_PROGRAM(obj) \
                (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
                 OSSO_ABOOK_TYPE_PROGRAM, \
                 OssoABookProgram))
#define OSSO_ABOOK_PROGRAM_CLASS(klass) \
                (G_TYPE_CHECK_CLASS_CAST ((klass), \
                 OSSO_ABOOK_TYPE_PROGRAM, \
                 OssoABookProgramClass))
#define OSSO_ABOOK_IS_PROGRAM(obj) \
                (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
                 OSSO_ABOOK_TYPE_PROGRAM))
#define OSSO_ABOOK_IS_PROGRAM_CLASS(klass) \
                (G_TYPE_CHECK_CLASS_TYPE ((klass), \
                 OSSO_ABOOK_TYPE_PROGRAM))
#define OSSO_ABOOK_PROGRAM_GET_CLASS(obj) \
                (G_TYPE_INSTANCE_GET_CLASS ((obj), \
                 OSSO_ABOOK_TYPE_PROGRAM, \
                 OssoABookProgramClass))

typedef struct {
	GObject parent;
} OssoABookProgram;

typedef enum {
        OSSO_ABOOK_MC_ACCOUNT_CHANGE_CREATED,
        OSSO_ABOOK_MC_ACCOUNT_CHANGE_DELETED,
        OSSO_ABOOK_MC_ACCOUNT_CHANGE_CHANGED,
        OSSO_ABOOK_MC_ACCOUNT_CHANGE_ENABLED,
        OSSO_ABOOK_MC_ACCOUNT_CHANGE_DISABLED,
        OSSO_ABOOK_MC_ACCOUNT_CHANGE_STATUS
} OssoABookMcAccountChange;

typedef struct {
	GObjectClass parent_class;

	void (*presence_changed) (OssoABookProgram *program,
				  McPresence        presence);
	void (*mc_account_changed) (OssoABookProgram *program,
				  OssoABookMcAccountChange);
        void (*used_channel_count_changed) (OssoABookProgram *program,
                                            guint             count);
} OssoABookProgramClass;

GType osso_abook_program_get_type (void);

OssoABookProgram *osso_abook_program_new (osso_context_t *ctxt);
MissionControl *osso_abook_program_get_mc (OssoABookProgram *program);
McPresence osso_abook_program_get_presence (OssoABookProgram *program);
TelepathyConnectionStatus osso_abook_program_get_account_status (OssoABookProgram *program, McAccount *account);
McAccount* osso_abook_program_get_mc_account (OssoABookProgram *program, const char *bound, const char *vcard_field);
guint osso_abook_program_get_used_channel_count (OssoABookProgram *program);
GList * osso_abook_program_get_primary_vcard_fields (OssoABookProgram * self);
GList * osso_abook_program_get_secondary_vcard_fields (OssoABookProgram * self);
gboolean osso_abook_program_has_secondary_vcard_field (OssoABookProgram *self, const char *vcard_field);

G_END_DECLS

#endif
